# Legen Sie los!

Willkommen bei Rapunzel, einer modernen Entwicklungsumgebung für Python und R. Hier sind ein paar praktische Tastenkombinationen.


## Arbeiten mit Projektordnern und Dateien

- [`Strg+Umschalt+O`: Projektordner öffnen](opensesame://event.rapunzel_welcome_open_folders)
- [`Strg+O`: Datei aus Projektordnern öffnen](opensesame://event.rapunzel_welcome_open_files)
- [`Strg+N`: Leeres Dokument erstellen](opensesame://event.ide_new_file)


## Schnell Dinge erledigen

- [`Strg+Umschalt+P`: Befehlspalette aktivieren](opensesame://event.command_palette_activate)
- `Strg+R`: Zu Funktion oder Klasse springen


## Code ausführen

- `F5`: Projekt oder Datei ausführen
- `F9`: Auswahl, Zelle oder aktuelle Zeile ausführen